import router from './router'
import NProgress from 'nprogress'
import store from './store'
import 'nprogress/nprogress.css'
import { getToken } from '@/util/auth'

NProgress.configure({ showSpinner: false })

const whiteList = ['/login', '/pwlogin', '/forgotPW', '/goods-detail', '/order-list', '/share', '/order-detail', '/order-pay', '/paymentOnline', '/paymentOffline', '/wechatpay']

router.beforeEach((to, from, next) => {
  NProgress.start()
  if (getToken()) {
    /* has token */
    if (to.meta.title) {
      document.title = to.meta.title
    }
    if (to.path === '/login' || to.path === '/pwlogin') {
      next({ path: '/pwlogin' })
      NProgress.done()
    } else {
      if (!store.getters.userInfo) {
        store.dispatch('user/getUserInfo', store.getters.userId).then(() => {
          store.dispatch('institution/addressList').then(() => {
            next()
          })
        }).catch(err => {
          console.log(err)
          store.dispatch('user/loginOut').then(() => {
            next({ path: '/pwlogin' })
          })
        })
      } else {
        next()
      }
    }
  } else {
    // 没有token
    if (whiteList.indexOf(to.path) !== -1) {
      next()
      // 在免登录白名单，直接进入
    } else {
      next(`/pwlogin?redirect=${to.fullPath}`) // 否则全部重定向到登录页
      NProgress.done()
    }
  }
})

router.afterEach(() => {
  NProgress.done()
})
