import Vue from 'vue'
import VueRouter from 'vue-router'

Vue.use(VueRouter)

const routes = [
  {
    path: '/',
    redirect: '/shopping-mall'
  },
  {
    path: '/login',
    name: 'login',
    component: () => import(/* webpackChunkName: "login" */ '@/views/login/login.vue'),
    meta: {
      transition: 'slide-left',
      title: '登录'
    }
  },
  {
    path: '/pwlogin',
    name: 'pwlogin',
    component: () => import(/* webpackChunkName: "register" */ '@/views/login/pwlogin.vue'),
    meta: {
      transition: 'slide-right',
      title: '登录'
    }
  },
  {
    path: '/forgotPW',
    name: 'forgotPW',
    component: () => import(/* webpackChunkName: "register" */ '@/views/login/forgotPW.vue'),
    meta: {
      transition: 'slide-right',
      title: '修改密码'
    }
  },
  {
    path: '/shopping-mall',
    name: 'shopping-mall',
    component: () => import('@/Layout/index.vue'),
    children: [
      {
        path: '/',
        component: () => import('@/views/shopping-mall/index.vue'),
        meta: {
          title: '分销系统'
        }
      }
    ]
  },
  {
    path: '/mine',
    name: 'mine',
    component: () => import('@/Layout/index.vue'),
    children: [
      {
        path: '/',
        component: () => import('@/views/mine/index.vue'),
        meta: {
          title: '个人中心'
        }
      }
    ]
  },
  {
    path: '/goods-detail',
    name: 'goods-detail',
    component: () => import('@/views/shopping-mall/detail.vue'),
    meta: {
      title: '商品详情'
    }
  },
  {
    path: '/my-team',
    name: 'my-team',
    component: () => import('@/views/my-team/index.vue'),
    meta: {
      title: '团队成员'
    }
  },
  {
    path: '/addTeam',
    name: 'addTeam',
    component: () => import('@/views/my-team/addTeam.vue'),
    meta: {
      title: '添加成员'
    }
  },
  {
    path: '/order-report',
    name: 'order-report',
    component: () => import('@/views/order-report/index.vue'),
    meta: {
      title: '订单报备佣金'
    }
  },
  {
    path: '/order-report-detail',
    name: 'order-report-detail',
    component: () => import('@/views/order-report/detail.vue'),
    meta: {
      title: '订单报备佣金详情'
    }
  },
  {
    path: '/mine-card',
    name: 'mine-card',
    component: () => import('@/views/mine-card/index.vue'),
    meta: {
      title: '我的名片'
    }
  },
  {
    path: '/mine-qrcode',
    name: 'mine-qrcode',
    component: () => import('@/views/mine-card/qrcode.vue'),
    meta: {
      title: '我的名片'
    }
  },
  {
    path: '/save-card',
    name: 'save-card',
    component: () => import('@/views/mine-card/save-card.vue'),
    meta: {
      title: '我的名片'
    }
  },
  {
    path: '/account-settings',
    name: 'account-settings',
    component: () => import('@/views/login/account-settings.vue'),
    meta: {
      title: '账户设置'
    }
  },
  {
    path: '/order-sales',
    name: 'order-sales',
    component: () => import('@/views/order-sales/index.vue'),
    meta: {
      title: '订单销售佣金'
    }
  },
  {
    path: '/order-sales-detail',
    name: 'order-sales-detail',
    component: () => import('@/views/order-sales/detail.vue'),
    meta: {
      title: '订单销售佣金详情'
    }
  },
  {
    path: '/goods-information',
    name: 'goods-information',
    component: () => import('@/views/goods-information/index.vue'),
    meta: {
      title: '商品详情'
    }
  },
  {
    path: '/goods-information-detail',
    name: 'goods-information-detail',
    component: () => import('@/views/goods-information/detail.vue'),
    meta: {
      title: '商品详情'
    }
  },
  {
    path: '/ins-intention-report',
    name: 'ins-intention-report',
    component: () => import('@/views/ins-intention-report/index.vue'),
    meta: {
      title: '机构意向订单报备'
    }
  },
  {
    path: '/ins-intention-detail',
    name: 'ins-intention-detail',
    component: () => import('@/views/ins-intention-report/detail.vue'),
    meta: {
      title: '详情'
    }
  },
  {
    path: '/ins-intention-add',
    name: 'ins-intention-add',
    component: () => import('@/views/ins-intention-report/add.vue'),
    meta: {
      title: '添加报备'
    }
  },
  {
    path: '/order-list',
    name: 'order-list',
    component: () => import('@/views/order-list/index.vue'),
    meta: {
      title: '订单列表'
    }
  },
  {
    path: '/order-create',
    name: 'order-create',
    component: () => import('@/views/order-list/order-create.vue'),
    meta: {
      title: '确认订单'
    }
  },
  {
    path: '/order-pay',
    name: 'order-pay',
    component: () => import('@/views/order-list/order-pay.vue'),
    meta: {
      title: '支付订单'
    }
  },
  {
    path: '/address-select',
    name: 'address-select',
    component: () => import('@/views/order-list/address-select.vue'),
    meta: {
      title: '切换地址'
    }
  },
  {
    path: '/address-edit',
    name: 'address-edit',
    component: () => import('@/views/order-list/address-edit.vue'),
    meta: {
      title: '编辑地址'
    }
  },
  {
    path: '/order-detail',
    name: 'order-detail',
    component: () => import('@/views/order-list/order-detail.vue'),
    meta: {
      title: '订单详情'
    }
  },
  {
    path: '/intention-confirm',
    name: 'intention-confirm',
    component: () => import('@/views/ins-intention-report/intention-confirm.vue'),
    meta: {
      title: '意向订单确认'
    }
  },
  {
    path: '/upload-voucher',
    name: 'upload-voucher',
    component: () => import('@/views/order-list/order-upload-voucher.vue'),
    meta: {
      title: '上传支付凭证'
    }
  },
  {
    path: '/share',
    name: 'share',
    component: () => import('@/views/share/index.vue'),
    meta: {
      title: '分享'
    }
  },
  {
    path: '/paymentOffline',
    name: 'paymentOffline',
    component: () => import('@/views/pay/paymentOffline.vue'),
    meta: {
      title: '线下转账'
    }
  },
  {
    path: '/paymentOnline',
    name: 'paymentOnline',
    component: () => import('@/views/pay/paymentOnline.vue'),
    meta: {
      title: '线上支付'
    }
  },
  {
    path: '/orderLogistics',
    name: 'orderLogistics',
    component: () => import('@/views/order-list/orderLogistics.vue'),
    meta: {
      title: '查看物流'
    }
  },
  {
    path: '/wechatpay',
    name: 'wechatpay',
    component: () => import('@/views/pay/wechatPay.vue'),
    meta: {
      title: '微信支付'
    }
  },
  {
    path: '/addBanks',
    name: 'addBanks',
    component: () => import('@/views/pay/addBanks.vue'),
    meta: {
      title: '添加银行卡'
    }
  },
  {
    path: '/card-comfirm-sub',
    name: 'card-comfirm-sub',
    component: () => import('@/views/pay/card-comfirm-sub.vue'),
    meta: {
      title: '添加银行卡'
    }
  }
]

const router = new VueRouter({
  mode: 'history',
  base: '',
  routes
})

export default router
